@@ -2,7 +2,6 @@
 module Events.HECs (
     HECs(..),
     Event,
-    CapEvent,
     Timestamp,
 
     eventIndexToTimestamp,
@@ -17,16 +16,21 @@ import Events.SparkTree
 import GHC.RTS.Events
 
 import Data.Array
-import qualified Data.IntMap as IM
 import qualified Data.List as L
 
+#if MIN_VERSION_containers(0,5,0)
+import qualified Data.IntMap.Strict as IM
+#else
+import qualified Data.IntMap as IM
+#endif
+
 -----------------------------------------------------------------------------
 
 -- all the data from a .eventlog file
 data HECs = HECs {
        hecCount         :: Int,
        hecTrees         :: [(DurationTree, EventTree, SparkTree)],
-       hecEventArray    :: Array Int CapEvent,
+       hecEventArray    :: Array Int Event,
        hecLastEventTime :: Timestamp,
        maxSparkPool     :: Double,
        minXHistogram    :: Int,
@@ -40,7 +44,7 @@ data HECs = HECs {
 
 eventIndexToTimestamp :: HECs -> Int -> Timestamp
 eventIndexToTimestamp HECs{hecEventArray=arr} n =
-  time (ce_event (arr ! n))
+  evTime (arr ! n)
 
 timestampToEventIndex :: HECs -> Timestamp -> Int
 timestampToEventIndex HECs{hecEventArray=arr} ts =
@@ -49,17 +53,17 @@ timestampToEventIndex HECs{hecEventArray=arr} ts =
     (l,r) = bounds arr
 
     search !l !r
-      | (r - l) <= 1 = if ts > time (ce_event (arr!l)) then r else l
+      | (r - l) <= 1 = if ts > evTime (arr!l) then r else l
       | ts < tmid    = search l mid
       | otherwise    = search mid r
       where
         mid  = l + (r - l) `quot` 2
-        tmid = time (ce_event (arr!mid))
+        tmid = evTime (arr!mid)
 
 extractUserMarkers :: HECs -> [(Timestamp, String)]
 extractUserMarkers hecs =
   [ (ts, mark)
-  | CapEvent _ (Event ts (UserMarker mark)) <- elems (hecEventArray hecs) ]
+  | (Event ts (UserMarker mark) _) <- elems (hecEventArray hecs) ]
 
 -- | Sum durations in the same buckets to form a histogram.
 histogram :: [(Int, Timestamp)] -> [(Int, Timestamp)]
@@ -79,7 +83,9 @@ fromListWith' :: (a -> a -> a) -> [(Int, a)] -> IM.IntMap a
 fromListWith' f xs =
     L.foldl' ins IM.empty xs
   where
-#if MIN_VERSION_containers(0,4,1)
+#if MIN_VERSION_containers(0,5,0)
+    ins t (k,x) = IM.insertWith f k x t
+#elif MIN_VERSION_containers(0,4,1)
     ins t (k,x) = IM.insertWith' f k x t
 #else
     ins t (k,x) =
