@@ -1,4 +1,5 @@
 {-# LANGUAGE CPP #-}
+{-# LANGUAGE TemplateHaskell #-}
 module GUI.Main (runGUI) where
 
 -- Imports for GTK
@@ -7,23 +8,21 @@ import System.Glib.GError (failOnGError)
 
 -- Imports from Haskell library
 import Text.Printf
-import Control.Monad
 #ifndef mingw32_HOST_OS
 import System.Posix
 #endif
 import Control.Concurrent
 import qualified Control.Concurrent.Chan as Chan
 import Control.Exception
-import Prelude hiding (catch)
 import Data.Array
 import Data.Maybe
 
-import Paths_threadscope
-
 -- Imports for ThreadScope
+import qualified GUI.App as App
 import qualified GUI.MainWindow as MainWindow
 import GUI.Types
 import Events.HECs hiding (Event)
+import GUI.DataFiles (ui)
 import GUI.Dialogs
 import Events.ReadEvents
 import GUI.EventsView
@@ -118,7 +117,7 @@ constructUI :: IO UIEnv
 constructUI = failOnGError $ do
 
   builder <- Gtk.builderNew
-  Gtk.builderAddFromFile builder =<< getDataFileName "threadscope.ui"
+  Gtk.builderAddFromString builder $ui
 
   eventQueue <- Chan.newChan
   let post = postEvent eventQueue
@@ -445,6 +444,8 @@ runGUI :: Maybe (Either FilePath String) -> IO ()
 runGUI initialTrace = do
   Gtk.initGUI
 
+  App.initApp
+
   uiEnv <- constructUI
 
   let post = postEvent (eventQueue uiEnv)
